# CK AstroTools

General tools for astronomy I personally use regularly for data analysis.

**Status:**  Alpha\
**Author:** Carsten König\
**Repository:** https://gitlab.com/ck2go/ckastrotools \
**PyPi:** https://pypi.org/project/CKAstroTools/ \
**Documentation:** https://ckastrotools.readthedocs.io/en/latest/

## Purpose

Providing common tools, functions, workflows that I use for my everyday scientific work.

## Installation

```bash
pip install ckastrotools
```

## How to use
Import modules and use the objects or functions.


## License
[MIT License](https://choosealicense.com/licenses/mit/)

## Author
**Carsten König**

- [GitLab](https://gitlab.com/ck2go "Carsten König")
- [GitHub](https://github.com/ck2go "Carsten König")
- [LinkedIn](https://www.linkedin.com/in/ck2go/ "Carsten König")
- [Website](https://www.carsten-koenig.de "Carsten König")

